@@ -14,6 +14,14 @@ class TestApp(npyscreen.NPSApp):
         
         
         t2 = F.add(npyscreen.BoxTitle, name="Box Title:", max_height=6)
+        t3 = F.add(npyscreen.BoxTitle, name="Box Title2:", max_height=6,
+                        scroll_exit = True,
+                        contained_widget_arguments={
+                                'color': "WARNING", 
+                                'widgets_inherit_color': True,}
+                        )
+        
+        
         t2.entry_widget.scroll_exit = True
         t2.values = ["Hello", 
             "This is a Test", 
@@ -21,6 +29,8 @@ class TestApp(npyscreen.NPSApp):
             "And here is another line",
             "And here is another line, which is really very long.  abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz",
             "And one more."]
+        t3.values = t2.values
+        
         
         F.edit()
         
