@@ -17,7 +17,6 @@ class TitleText(widget.Widget):
         allow_override_begin_entry_at=True,
         **keywords):
         
-        self.hidden = hidden
         self.text_field_begin_at = begin_entry_at
         self.field_width_request = field_width
         self.labelColor = labelColor
@@ -69,6 +68,8 @@ class TitleText(widget.Widget):
 
         self.make_contained_widgets()
         self.set_value(value)
+        self.hidden = hidden
+        
         
     
     def resize(self):
@@ -98,7 +99,8 @@ class TitleText(widget.Widget):
         else: 
             self._contained_rely_offset = 0
                 
-        self.entry_widget = self.__class__._entry_type(self.parent, relx=(self.relx + self.text_field_begin_at), 
+        self.entry_widget = self.__class__._entry_type(self.parent, 
+                                relx=(self.relx + self.text_field_begin_at), 
                                 rely=(self.rely+self._contained_rely_offset), value = self.value,
                                 **self._passon)
         self.entry_widget.parent_widget = weakref.proxy(self)
@@ -168,6 +170,11 @@ class TitleText(widget.Widget):
         except AttributeError:
             self._editable = value
 
+    def add_handlers(self, handler_dictionary):
+        """
+        Pass handlers to entry_widget
+        """
+        self.entry_widget.add_handlers(handler_dictionary)
 
 class TitleFixedText(TitleText):
     _entry_type = textbox.FixedText
